# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to 
[Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.2.0
    * (added) Defined themes to style the objects inside the dialog

## 0.1.3
    * Update to the changelog

## 0.1.2
    * Minor bug fixes

## 0.1.1
    * Minor bug fixes

## 0.1.0
    * Initial Release